Allele frequencies
==================

.. automodule:: anhima.af
.. autofunction:: allelism
.. autofunction:: allele_number
.. autofunction:: allele_count
.. autofunction:: allele_frequency
.. autofunction:: allele_counts
.. autofunction:: allele_frequencies
.. autofunction:: is_variant
.. autofunction:: is_non_variant
.. autofunction:: is_segregating
.. autofunction:: is_non_segregating
.. autofunction:: is_singleton
.. autofunction:: is_doubleton
.. autofunction:: count_variant
.. autofunction:: count_non_variant
.. autofunction:: count_segregating
.. autofunction:: count_non_segregating
.. autofunction:: count_singletons
.. autofunction:: count_doubletons
.. autofunction:: maximum_likelihood_ancestry
